==> sddm_0.11.0.orig.tar.gz: sddm-0.11.0/src/daemon/XorgDisplayServer.h <==
/***************************************************************************
* Copyright (c) 2014 Pier Luigi Fiorini <pierluigi.fiorini@gmail.com>
* Copyright (c) 2013 Abdurrahman AVCI <abdurrahmanavci@gmail.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the
* Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
***************************************************************************/

#ifndef SDDM_XORGDISPLAYSERVER_H
#define SDDM_XORGDISPLAYSERVER_H

#include "DisplayServer.h"

class QProcess;

namespace SDDM {
    class XorgDisplayServer : public DisplayServer {
        Q_OBJECT
        Q_DISABLE_COPY(XorgDisplayServer)
    public:
        explicit XorgDisplayServer(Display *parent);
        ~XorgDisplayServer();

        static bool displayExists(int number);

        const QString &display() const;
        const QString &authPath() const;

        QString sessionType() const;

        const QString &cookie() const;

        void addCookie(const QString &file);

    public slots:
        bool start();
        void stop();
        void finished();
        void setupDisplay();

    private:
        QString m_authPath { "" };
        QString m_cookie { "" };

        QProcess *process { nullptr };

        void changeOwner(const QString &fileName);
    };
}

#endif // SDDM_XORGDISPLAYSERVER_H

==> sddm_0.14.0.orig.tar.gz: sddm-0.14.0/src/daemon/XorgDisplayServer.h <==
/***************************************************************************
* Copyright (c) 2014 Pier Luigi Fiorini <pierluigi.fiorini@gmail.com>
* Copyright (c) 2013 Abdurrahman AVCI <abdurrahmanavci@gmail.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the
* Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
***************************************************************************/

#ifndef SDDM_XORGDISPLAYSERVER_H
#define SDDM_XORGDISPLAYSERVER_H

#include "DisplayServer.h"

class QProcess;

namespace SDDM {
    class XorgDisplayServer : public DisplayServer {
        Q_OBJECT
        Q_DISABLE_COPY(XorgDisplayServer)
    public:
        explicit XorgDisplayServer(Display *parent);
        ~XorgDisplayServer();

        const QString &display() const;
        const QString &authPath() const;

        QString sessionType() const;

        const QString &cookie() const;

        void addCookie(const QString &file);

    public slots:
        bool start();
        void stop();
        void finished();
        void setupDisplay();

    private:
        QString m_authPath;
        QString m_cookie;

        QProcess *process { nullptr };

        void changeOwner(const QString &fileName);
    };
}

#endif // SDDM_XORGDISPLAYSERVER_H
